==> zio-aws-imagebuilder_2.13-5.17.181.1-sources.jar: zio/aws/imagebuilder/model/UpdateInfrastructureConfigurationRequest.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  InstanceProfileNameType,
  InfrastructureConfigurationArn,
  TagValue,
  SnsTopicArn,
  InstanceType,
  ClientToken,
  NullableBoolean,
  NonEmptyString,
  TagKey
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateInfrastructureConfigurationRequest(
    infrastructureConfigurationArn: InfrastructureConfigurationArn,
    description: Optional[NonEmptyString] = Optional.Absent,
    instanceTypes: Optional[Iterable[InstanceType]] = Optional.Absent,
    instanceProfileName: InstanceProfileNameType,
    securityGroupIds: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    subnetId: Optional[NonEmptyString] = Optional.Absent,
    logging: Optional[zio.aws.imagebuilder.model.Logging] = Optional.Absent,
    keyPair: Optional[NonEmptyString] = Optional.Absent,
    terminateInstanceOnFailure: Optional[NullableBoolean] = Optional.Absent,
    snsTopicArn: Optional[SnsTopicArn] = Optional.Absent,
    clientToken: ClientToken,
    resourceTags: Optional[Map[TagKey, TagValue]] = Optional.Absent,
    instanceMetadataOptions: Optional[
      zio.aws.imagebuilder.model.InstanceMetadataOptions
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest = {
    import UpdateInfrastructureConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
      .builder()
      .infrastructureConfigurationArn(
        InfrastructureConfigurationArn.unwrap(
          infrastructureConfigurationArn
        ): java.lang.String
      )
      .optionallyWith(
        description.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        instanceTypes.map(value =>
          value.map { item =>
            InstanceType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.instanceTypes)
      .instanceProfileName(
        InstanceProfileNameType.unwrap(instanceProfileName): java.lang.String
      )
      .optionallyWith(
        securityGroupIds.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupIds)
      .optionallyWith(
        subnetId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(logging.map(value => value.buildAwsValue()))(_.logging)
      .optionallyWith(
        keyPair.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.keyPair)
      .optionallyWith(
        terminateInstanceOnFailure.map(value => value: java.lang.Boolean)
      )(_.terminateInstanceOnFailure)
      .optionallyWith(
        snsTopicArn.map(value => SnsTopicArn.unwrap(value): java.lang.String)
      )(_.snsTopicArn)
      .clientToken(ClientToken.unwrap(clientToken): java.lang.String)
      .optionallyWith(
        resourceTags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.resourceTags)
      .optionallyWith(
        instanceMetadataOptions.map(value => value.buildAwsValue())
      )(_.instanceMetadataOptions)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest.ReadOnly =
    zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateInfrastructureConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest =
      zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest(
        infrastructureConfigurationArn,
        description.map(value => value),
        instanceTypes.map(value => value),
        instanceProfileName,
        securityGroupIds.map(value => value),
        subnetId.map(value => value),
        logging.map(value => value.asEditable),
        keyPair.map(value => value),
        terminateInstanceOnFailure.map(value => value),
        snsTopicArn.map(value => value),
        clientToken,
        resourceTags.map(value => value),
        instanceMetadataOptions.map(value => value.asEditable)
      )
    def infrastructureConfigurationArn: InfrastructureConfigurationArn
    def description: Optional[NonEmptyString]
    def instanceTypes: Optional[List[InstanceType]]
    def instanceProfileName: InstanceProfileNameType
    def securityGroupIds: Optional[List[NonEmptyString]]
    def subnetId: Optional[NonEmptyString]
    def logging: Optional[zio.aws.imagebuilder.model.Logging.ReadOnly]
    def keyPair: Optional[NonEmptyString]
    def terminateInstanceOnFailure: Optional[NullableBoolean]
    def snsTopicArn: Optional[SnsTopicArn]
    def clientToken: ClientToken
    def resourceTags: Optional[Map[TagKey, TagValue]]
    def instanceMetadataOptions
        : Optional[zio.aws.imagebuilder.model.InstanceMetadataOptions.ReadOnly]
    def getInfrastructureConfigurationArn
        : ZIO[Any, Nothing, InfrastructureConfigurationArn] =
      ZIO.succeed(infrastructureConfigurationArn)
    def getDescription: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("description", description)
    def getInstanceTypes: ZIO[Any, AwsError, List[InstanceType]] =
      AwsError.unwrapOptionField("instanceTypes", instanceTypes)
    def getInstanceProfileName: ZIO[Any, Nothing, InstanceProfileNameType] =
      ZIO.succeed(instanceProfileName)
    def getSecurityGroupIds: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("securityGroupIds", securityGroupIds)
    def getSubnetId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getLogging
        : ZIO[Any, AwsError, zio.aws.imagebuilder.model.Logging.ReadOnly] =
      AwsError.unwrapOptionField("logging", logging)
    def getKeyPair: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("keyPair", keyPair)
    def getTerminateInstanceOnFailure: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField(
        "terminateInstanceOnFailure",
        terminateInstanceOnFailure
      )
    def getSnsTopicArn: ZIO[Any, AwsError, SnsTopicArn] =
      AwsError.unwrapOptionField("snsTopicArn", snsTopicArn)
    def getClientToken: ZIO[Any, Nothing, ClientToken] =
      ZIO.succeed(clientToken)
    def getResourceTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("resourceTags", resourceTags)
    def getInstanceMetadataOptions: ZIO[
      Any,
      AwsError,
      zio.aws.imagebuilder.model.InstanceMetadataOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "instanceMetadataOptions",
      instanceMetadataOptions
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
  ) extends zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest.ReadOnly {
    override val infrastructureConfigurationArn
        : InfrastructureConfigurationArn = zio.aws.imagebuilder.model.primitives
      .InfrastructureConfigurationArn(impl.infrastructureConfigurationArn())
    override val description: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val instanceTypes: Optional[List[InstanceType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instanceTypes())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.imagebuilder.model.primitives.InstanceType(item)
          }.toList
        )
    override val instanceProfileName: InstanceProfileNameType =
      zio.aws.imagebuilder.model.primitives
        .InstanceProfileNameType(impl.instanceProfileName())
    override val securityGroupIds: Optional[List[NonEmptyString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityGroupIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.imagebuilder.model.primitives.NonEmptyString(item)
          }.toList
        )
    override val subnetId: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val logging
        : Optional[zio.aws.imagebuilder.model.Logging.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.logging())
        .map(value => zio.aws.imagebuilder.model.Logging.wrap(value))
    override val keyPair: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.keyPair())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val terminateInstanceOnFailure: Optional[NullableBoolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.terminateInstanceOnFailure())
        .map(value => value: NullableBoolean)
    override val snsTopicArn: Optional[SnsTopicArn] = zio.aws.core.internal
      .optionalFromNullable(impl.snsTopicArn())
      .map(value => zio.aws.imagebuilder.model.primitives.SnsTopicArn(value))
    override val clientToken: ClientToken =
      zio.aws.imagebuilder.model.primitives.ClientToken(impl.clientToken())
    override val resourceTags: Optional[Map[TagKey, TagValue]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceTags())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.imagebuilder.model.primitives.TagKey(
                key
              ) -> zio.aws.imagebuilder.model.primitives.TagValue(value)
            })
            .toMap
        )
    override val instanceMetadataOptions: Optional[
      zio.aws.imagebuilder.model.InstanceMetadataOptions.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceMetadataOptions())
      .map(value =>
        zio.aws.imagebuilder.model.InstanceMetadataOptions.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
  ): zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-imagebuilder_3-7.31.0.1-sources.jar: zio/aws/imagebuilder/model/UpdateInfrastructureConfigurationRequest.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  InstanceProfileNameType,
  InfrastructureConfigurationArn,
  TagValue,
  SnsTopicArn,
  InstanceType,
  ClientToken,
  NullableBoolean,
  NonEmptyString,
  TagKey
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateInfrastructureConfigurationRequest(
    infrastructureConfigurationArn: InfrastructureConfigurationArn,
    description: Optional[NonEmptyString] = Optional.Absent,
    instanceTypes: Optional[Iterable[InstanceType]] = Optional.Absent,
    instanceProfileName: InstanceProfileNameType,
    securityGroupIds: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    subnetId: Optional[NonEmptyString] = Optional.Absent,
    logging: Optional[zio.aws.imagebuilder.model.Logging] = Optional.Absent,
    keyPair: Optional[NonEmptyString] = Optional.Absent,
    terminateInstanceOnFailure: Optional[NullableBoolean] = Optional.Absent,
    snsTopicArn: Optional[SnsTopicArn] = Optional.Absent,
    resourceTags: Optional[Map[TagKey, TagValue]] = Optional.Absent,
    instanceMetadataOptions: Optional[
      zio.aws.imagebuilder.model.InstanceMetadataOptions
    ] = Optional.Absent,
    placement: Optional[zio.aws.imagebuilder.model.Placement] = Optional.Absent,
    clientToken: ClientToken
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest = {
    import UpdateInfrastructureConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
      .builder()
      .infrastructureConfigurationArn(
        InfrastructureConfigurationArn.unwrap(
          infrastructureConfigurationArn
        ): java.lang.String
      )
      .optionallyWith(
        description.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        instanceTypes.map(value =>
          value.map { item =>
            InstanceType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.instanceTypes)
      .instanceProfileName(
        InstanceProfileNameType.unwrap(instanceProfileName): java.lang.String
      )
      .optionallyWith(
        securityGroupIds.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupIds)
      .optionallyWith(
        subnetId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(logging.map(value => value.buildAwsValue()))(_.logging)
      .optionallyWith(
        keyPair.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.keyPair)
      .optionallyWith(
        terminateInstanceOnFailure.map(value => value: java.lang.Boolean)
      )(_.terminateInstanceOnFailure)
      .optionallyWith(
        snsTopicArn.map(value => SnsTopicArn.unwrap(value): java.lang.String)
      )(_.snsTopicArn)
      .optionallyWith(
        resourceTags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.resourceTags)
      .optionallyWith(
        instanceMetadataOptions.map(value => value.buildAwsValue())
      )(_.instanceMetadataOptions)
      .optionallyWith(placement.map(value => value.buildAwsValue()))(
        _.placement
      )
      .clientToken(ClientToken.unwrap(clientToken): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest.ReadOnly =
    zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateInfrastructureConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest =
      zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest(
        infrastructureConfigurationArn,
        description.map(value => value),
        instanceTypes.map(value => value),
        instanceProfileName,
        securityGroupIds.map(value => value),
        subnetId.map(value => value),
        logging.map(value => value.asEditable),
        keyPair.map(value => value),
        terminateInstanceOnFailure.map(value => value),
        snsTopicArn.map(value => value),
        resourceTags.map(value => value),
        instanceMetadataOptions.map(value => value.asEditable),
        placement.map(value => value.asEditable),
        clientToken
      )
    def infrastructureConfigurationArn: InfrastructureConfigurationArn
    def description: Optional[NonEmptyString]
    def instanceTypes: Optional[List[InstanceType]]
    def instanceProfileName: InstanceProfileNameType
    def securityGroupIds: Optional[List[NonEmptyString]]
    def subnetId: Optional[NonEmptyString]
    def logging: Optional[zio.aws.imagebuilder.model.Logging.ReadOnly]
    def keyPair: Optional[NonEmptyString]
    def terminateInstanceOnFailure: Optional[NullableBoolean]
    def snsTopicArn: Optional[SnsTopicArn]
    def resourceTags: Optional[Map[TagKey, TagValue]]
    def instanceMetadataOptions
        : Optional[zio.aws.imagebuilder.model.InstanceMetadataOptions.ReadOnly]
    def placement: Optional[zio.aws.imagebuilder.model.Placement.ReadOnly]
    def clientToken: ClientToken
    def getInfrastructureConfigurationArn
        : ZIO[Any, Nothing, InfrastructureConfigurationArn] =
      ZIO.succeed(infrastructureConfigurationArn)
    def getDescription: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("description", description)
    def getInstanceTypes: ZIO[Any, AwsError, List[InstanceType]] =
      AwsError.unwrapOptionField("instanceTypes", instanceTypes)
    def getInstanceProfileName: ZIO[Any, Nothing, InstanceProfileNameType] =
      ZIO.succeed(instanceProfileName)
    def getSecurityGroupIds: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("securityGroupIds", securityGroupIds)
    def getSubnetId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getLogging
        : ZIO[Any, AwsError, zio.aws.imagebuilder.model.Logging.ReadOnly] =
      AwsError.unwrapOptionField("logging", logging)
    def getKeyPair: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("keyPair", keyPair)
    def getTerminateInstanceOnFailure: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField(
        "terminateInstanceOnFailure",
        terminateInstanceOnFailure
      )
    def getSnsTopicArn: ZIO[Any, AwsError, SnsTopicArn] =
      AwsError.unwrapOptionField("snsTopicArn", snsTopicArn)
    def getResourceTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("resourceTags", resourceTags)
    def getInstanceMetadataOptions: ZIO[
      Any,
      AwsError,
      zio.aws.imagebuilder.model.InstanceMetadataOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "instanceMetadataOptions",
      instanceMetadataOptions
    )
    def getPlacement
        : ZIO[Any, AwsError, zio.aws.imagebuilder.model.Placement.ReadOnly] =
      AwsError.unwrapOptionField("placement", placement)
    def getClientToken: ZIO[Any, Nothing, ClientToken] =
      ZIO.succeed(clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
  ) extends zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest.ReadOnly {
    override val infrastructureConfigurationArn
        : InfrastructureConfigurationArn = zio.aws.imagebuilder.model.primitives
      .InfrastructureConfigurationArn(impl.infrastructureConfigurationArn())
    override val description: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val instanceTypes: Optional[List[InstanceType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instanceTypes())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.imagebuilder.model.primitives.InstanceType(item)
          }.toList
        )
    override val instanceProfileName: InstanceProfileNameType =
      zio.aws.imagebuilder.model.primitives
        .InstanceProfileNameType(impl.instanceProfileName())
    override val securityGroupIds: Optional[List[NonEmptyString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityGroupIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.imagebuilder.model.primitives.NonEmptyString(item)
          }.toList
        )
    override val subnetId: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val logging
        : Optional[zio.aws.imagebuilder.model.Logging.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.logging())
        .map(value => zio.aws.imagebuilder.model.Logging.wrap(value))
    override val keyPair: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.keyPair())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val terminateInstanceOnFailure: Optional[NullableBoolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.terminateInstanceOnFailure())
        .map(value => value: NullableBoolean)
    override val snsTopicArn: Optional[SnsTopicArn] = zio.aws.core.internal
      .optionalFromNullable(impl.snsTopicArn())
      .map(value => zio.aws.imagebuilder.model.primitives.SnsTopicArn(value))
    override val resourceTags: Optional[Map[TagKey, TagValue]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceTags())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.imagebuilder.model.primitives.TagKey(
                key
              ) -> zio.aws.imagebuilder.model.primitives.TagValue(value)
            })
            .toMap
        )
    override val instanceMetadataOptions: Optional[
      zio.aws.imagebuilder.model.InstanceMetadataOptions.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceMetadataOptions())
      .map(value =>
        zio.aws.imagebuilder.model.InstanceMetadataOptions.wrap(value)
      )
    override val placement
        : Optional[zio.aws.imagebuilder.model.Placement.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.placement())
        .map(value => zio.aws.imagebuilder.model.Placement.wrap(value))
    override val clientToken: ClientToken =
      zio.aws.imagebuilder.model.primitives.ClientToken(impl.clientToken())
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateInfrastructureConfigurationRequest
  ): zio.aws.imagebuilder.model.UpdateInfrastructureConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
